@@ -138,7 +138,7 @@ textstat_collocations.tokens <- function(x, method = "lambda",
     
     attrs <- attributes(x)
     types <- types(x)
-    id_ignore <- unlist(regex2id("^\\p{P}+$", types, 'regex', FALSE), use.names = FALSE)
+    id_ignore <- unlist(pattern2id("^\\p{P}+$", types, 'regex', FALSE), use.names = FALSE)
     if (is.null(id_ignore)) id_ignore <- integer()
     result <- qatd_cpp_collocations(x, types, id_ignore, min_count, size, 
                                     if (method == "lambda1") "lambda1" else "lambda", 
