@@ -107,4 +107,11 @@ test_that("test wordfish predict methods", {
     expect_equal(names(pr3), c("fit", "se.fit"))
 })
 
+test_that("raises error when dfm is empty (#1419)",  {
+    
+    mx <- dfm_trim(data_dfm_lbgexample, 1000)
+    expect_error(textmodel_wordfish(mx),
+                 quanteda:::message_error("dfm_empty"))
+    
+})
 
