@@ -466,14 +466,6 @@ test_that("assignment operators are disabled for tokens object", {
     expect_error(toks[1] <- list(c(6, 100, 'z')), 'assignment to tokens objects is not allowed')
 })
 
-test_that("what = 'fasterword' works correctly", {
-    txt <- "\n \t  word"
-    expect_equal(as.list(tokens(txt, what = "fasterword", remove_separators = TRUE))[[1]],
-                 "word")
-    expect_equal(as.list(tokens(txt, what = "fasterword", remove_separators = FALSE))[[1]],
-                 c("\n", "\t", "word"))
-})
-
 test_that("empty tokens are removed correctly", {
     txt <- 'a   b  c d e '
     tok <- c('a', 'b', 'c', 'd', 'e')
@@ -517,3 +509,48 @@ test_that("combined tokens objects have all the attributes", {
     
 })
 
+test_that("tokens fasterword handles newlines correctly (#1447)", {
+    expect_identical(
+        as.list(tokens("one\ntwo\tthree", what = "fastestword", remove_separators = TRUE)),
+        list(text1 = c("one\ntwo\tthree"))
+    )
+    expect_identical(
+        suppressWarnings(as.list(tokens("one\ntwo\tthree", what = "fastestword", remove_separators = FALSE))),
+        list(text1 = c("one\ntwo\tthree"))
+    )
+    expect_identical(
+        as.list(tokens("one\ntwo\tthree", what = "fasterword", remove_separators = TRUE)),
+        list(text1 = c("one", "two", "three"))
+    )
+    expect_identical(
+        suppressWarnings(as.list(tokens("one\ntwo\tthree", what = "fasterword", remove_separators = FALSE))),
+        list(text1 = c("one", "two", "three"))
+    )
+    expect_identical(
+        as.list(tokens("one\ntwo\tthree", what = "word", remove_separators = TRUE)),
+        list(text1 = c("one", "two", "three"))
+    )
+    expect_identical(
+        as.list(tokens("one\ntwo\tthree", what = "word", remove_separators = FALSE)),
+        list(text1 = c("one", "\n", "two", "\t", "three"))
+    )
+})
+
+test_that("warn when remove_separators = FALSE fasterword and fastestword", {
+    expect_silent(tokens("a b c", what = "word"))
+    expect_warning(tokens("a b c", what = "fasterword", remove_separators = FALSE),
+                   "remove_separators = FALSE has no effect")
+    expect_warning(tokens("a b c", what = "fastestword", remove_separators = FALSE),
+                   "remove_separators = FALSE has no effect")
+})
+
+test_that("tokens_sample works as expected",{
+    toks <- tokens(data_corpus_inaugural[1:10])
+    expect_equal(ndoc(tokens_sample(toks, size = 5)), 5)
+    expect_equal(ndoc(tokens_sample(toks, size = 15, replace = TRUE)), 15)
+    expect_error(tokens_sample(toks, size = 20),
+                 "size cannot exceed the number of documents \\(10\\)")
+    expect_error(tokens_sample(data_corpus_inaugural[1:10]), 
+                 "only works on tokens objects")
+})
+
